==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Štítky",
    "Update" : "Aktualizovať",
    "Create" : "Vytvoriť",
    "Select tag…" : "Vyber štítok...",
    "Tagged files" : "Súbory so štítkom",
    "Select tags to filter by" : "Vybrať štítky pre filter",
    "No tags found" : "Štítky sa nenašli",
    "Please select tags to filter by" : "Vyberte štítky pre filtrovanie",
    "No files found for the selected tags" : "Neboli nájdené žiadne súbory označené vybranými štítkami",
    "Added system tag %1$s" : "Pridaný systémový štítok %1$s",
    "Added system tag {systemtag}" : "Pridaný systémový štítok {systemtag}",
    "%1$s added system tag %2$s" : "%1$s pridal(a) systémový štítok %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridal(a) systémový štítok {systemtag}",
    "Removed system tag %1$s" : "Odstránený systémový štítok %1$s",
    "Removed system tag {systemtag}" : "Odstránený systémový štítok {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s odstránil(a) systémový štítok %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You created system tag %1$s" : "Vytvorili ste systémový štítok %1$s",
    "You created system tag {systemtag}" : "Vytvorili ste systémový štítok {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvoril systémový štítok %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvoril(a) systémový štítok {systemtag}",
    "You deleted system tag %1$s" : "Zmazali ste systémový štítok %1$s",
    "You deleted system tag {systemtag}" : "Odstránili ste systémový štítok {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s zmazal(a) systémový štítok %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali ste systémový štítok %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali ste systémový štítok {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítok %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítok {oldsystemtag} na {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Pridali ste systémový štítok %2$s na %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} ste pridali systémový štítok {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s pridal(a) systémový štítok %3$s",
    "{actor} added system tag {systemtag} to {file}" : " {actor} k {file} pridal(a) systémový štítok {systemtag}",
    "You removed system tag %2$s from %1$s" : "Z %2$s ste odstránili systémový štítok %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} ste odstránili systémový štítok {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstránil(a) systémový štítok %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstránil(a) systémový štítok {systemtag} z {file}",
    "%s (restricted)" : "%s (obmedzené)",
    "%s (invisible)" : "%s (neviditeľné)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> súboru boli upravené",
    "Collaborative tags" : "Značky pre spoluprácu",
    "Create and edit collaborative tags. These tags affect all users." : "Vytvárajte a upravujte štítky pre spoluprácu. Tieto značky ovplyvnia všetkých používateľov.",
    "Select tag …" : "Vybrať štítok ...",
    "Name" : "Názov",
    "Delete" : "Zmazať",
    "Public" : "Verejné",
    "Restricted" : "Obmedzené",
    "Invisible" : "Neviditeľné",
    "Reset" : "Vynulovať",
    "No files in here" : "Žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Size" : "Veľkosť",
    "Modified" : "Upravené"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Štítky",
    "Update" : "Aktualizovať",
    "Create" : "Vytvoriť",
    "Select tag…" : "Vyber štítok...",
    "Tagged files" : "Súbory so štítkom",
    "Select tags to filter by" : "Vybrať štítky pre filter",
    "No tags found" : "Štítky sa nenašli",
    "Please select tags to filter by" : "Vyberte štítky pre filtrovanie",
    "No files found for the selected tags" : "Neboli nájdené žiadne súbory označené vybranými štítkami",
    "Added system tag %1$s" : "Pridaný systémový štítok %1$s",
    "Added system tag {systemtag}" : "Pridaný systémový štítok {systemtag}",
    "%1$s added system tag %2$s" : "%1$s pridal(a) systémový štítok %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridal(a) systémový štítok {systemtag}",
    "Removed system tag %1$s" : "Odstránený systémový štítok %1$s",
    "Removed system tag {systemtag}" : "Odstránený systémový štítok {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s odstránil(a) systémový štítok %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You created system tag %1$s" : "Vytvorili ste systémový štítok %1$s",
    "You created system tag {systemtag}" : "Vytvorili ste systémový štítok {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvoril systémový štítok %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvoril(a) systémový štítok {systemtag}",
    "You deleted system tag %1$s" : "Zmazali ste systémový štítok %1$s",
    "You deleted system tag {systemtag}" : "Odstránili ste systémový štítok {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s zmazal(a) systémový štítok %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali ste systémový štítok %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali ste systémový štítok {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítok %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítok {oldsystemtag} na {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Pridali ste systémový štítok %2$s na %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} ste pridali systémový štítok {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s pridal(a) systémový štítok %3$s",
    "{actor} added system tag {systemtag} to {file}" : " {actor} k {file} pridal(a) systémový štítok {systemtag}",
    "You removed system tag %2$s from %1$s" : "Z %2$s ste odstránili systémový štítok %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} ste odstránili systémový štítok {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstránil(a) systémový štítok %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstránil(a) systémový štítok {systemtag} z {file}",
    "%s (restricted)" : "%s (obmedzené)",
    "%s (invisible)" : "%s (neviditeľné)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> súboru boli upravené",
    "Collaborative tags" : "Značky pre spoluprácu",
    "Select tag …" : "Vybrať štítok ...",
    "Name" : "Názov",
    "Public" : "Verejné",
    "Restricted" : "Obmedzené",
    "Invisible" : "Neviditeľné",
    "Delete" : "Zmazať",
    "Reset" : "Vynulovať",
    "No files in here" : "Žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "Create and edit collaborative tags. These tags affect all users." : "Vytvárajte a upravujte štítky pre spoluprácu. Tieto značky ovplyvnia všetkých používateľov."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
